<?php
    if(!defined("DRSTATS"))
        die('No access');
    
    function __($key){
        return L12N::get($key);
    }
    
    class L12N{
        static private $translations = array();
        
        static private $defaultLang = 'en';
        static private $pageLang = 'en';
        static private $initialized = false;
        
        static public function setLang($lang){
            if(L12N::isValidLang($lang)){
                L12N::$pageLang = $lang;
                return true;
            }
            return false;
        }
        static public function getLang($lang){
            return L12N::$pageLang;
        }

        static public function isValidLang($lang){
            return (isset(L12N::$translations[$lang]));
        }
        
    
        static public function get($key, $lang = null){
            if(!L12N::$initialized){
                L12N::initialize();
                L12N::$initialized = true;
            }
            if($lang == null)
                $lang = L12N::$pageLang;

            if(isset(L12N::$translations[$lang][$key])){
                return L12N::$translations[$lang][$key];
            }
            if(isset(L12N::$translations[L12N::$defaultLang][$key])){
                return L12N::$translations[L12N::$defaultLang][$key];
            }
            return $key;
        }

        static public function initialize(){
            if(L12N::$initialized){
                return;
            }
            
            if ($handle = opendir('lang/')) {

                while (false !== ($file = readdir($handle))) {
                    if($file == '.' || $file == '..' || $file =='l12n.php')
                        continue;
                    
                    $lang = strtok($file, '-');
                    if(!isset(L12N::$translations[$lang])){
                        L12N::$translations[$lang] = array();
                    }

                    L12N::$translations[$lang] = array_merge(L12N::$translations[$lang], parse_ini_file("lang/{$file}"));
                }
                closedir($handle);
            }
        }
    }
?>
